@@ -553,8 +553,10 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 						toAdd.setLinkHost(col.getStringValue());
 					else if (col.getName().compareTo("LinkTitle") == 0) 
 						toAdd.setLinkTitle(col.getStringValue());
+					else if (col.getName().compareTo("IsApplicationFeed") == 0) 
+						toAdd.setApplicationFeed(col.getBooleanValue());
 					else {
-						_log.error("getAllPortalPrivacyLevelFeeds(): Could not assign variable to this Feed for column name: " + col.getName());
+						_log.warn("getAllPortalPrivacyLevelFeeds(): Could not assign variable to this Feed for column name: " + col.getName());
 					}
 				}
 				if (toAdd.getType() == FeedType.TWEET || toAdd.getType() == FeedType.SHARE || toAdd.getType() == FeedType.PUBLISH)
@@ -1385,6 +1387,9 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		else if (type.compareTo("COMMENT") == 0) {
 			return NotificationType.COMMENT;
 		}
+		else if (type.compareTo("MENTION") == 0) {
+			return NotificationType.MENTION;
+		}
 		else if (type.compareTo("LIKE") == 0) {
 			return NotificationType.LIKE;
 		}
